@@ -78,8 +78,8 @@ public:
   void on_box_reports_selected(const Glib::ustring& strName);
   void on_box_print_layouts_selected(const Glib::ustring& strName);
 
-  void on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction>& action, const Glib::RefPtr<Gtk::RadioAction>& operator_action);
-  void on_menu_userlevel_Operator(const Glib::RefPtr<Gtk::RadioAction>& action);
+  void on_menu_developer_developer(const Glib::RefPtr<Gtk::RadioAction>& action, const Glib::RefPtr<Gtk::RadioAction>& operator_action);
+  void on_menu_developer_operator(const Glib::RefPtr<Gtk::RadioAction>& action);
 
   void on_menu_file_export();
   void on_menu_file_import();
@@ -89,7 +89,7 @@ public:
   void on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>& action);
   void on_menu_file_print();
 
-  void on_menu_Mode_Toggle();
+  void on_menu_Edit_Find();
 
   //TODO: Actually put this in the menu for non-maemo too? #ifdef GLOM_ENABLE_MAEMO
   void on_menu_add_record();
@@ -113,7 +113,6 @@ public:
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_menu_Reports_EditReports();
-  void on_menu_File_EditPrintLayouts();
   void on_menu_developer_database_preferences();
   void on_menu_developer_fields();
   void do_menu_developer_fields(Gtk::Window& parent);
@@ -130,9 +129,7 @@ public:
   void on_developer_dialog_hide();
 
   void on_dialog_layout_report_hide();
-  void on_dialog_reports_hide();
   void on_dialog_layout_print_hide();
-  void on_dialog_print_layouts_hide();
 
   void on_dialog_add_related_table_request_edit_fields();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
@@ -173,7 +170,6 @@ public:
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void export_data_to_vector(Document::type_example_rows& the_vector, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
-  void export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
   void export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
 
   /** Show the table again. For instance, if the document has changed, or we want to display it differently.
@@ -257,16 +253,13 @@ private:
   Glib::ustring m_table_name;
 
   //Child widgets:
-  Gtk::Label* m_pLabel_Table;
-  Gtk::HBox* m_box_header;
-  Gtk::HBox* m_box_footer;
-  Gtk::Label* m_pLabel_Mode;
-  Gtk::Label* m_pLabel_userlevel;
+  Gtk::Label* m_pLabel_Table_DataMode;
+  Gtk::Label* m_pLabel_Table_FindMode;
 
-  Gtk::HBox* m_pBox_RecordsCount; //Only show this when in Data mode.
-  Gtk::Label* m_pLabel_RecordsCount;
-  Gtk::Label* m_pLabel_FoundCount;
-  Gtk::Button* m_pButton_FindAll;
+  Gtk::HBox m_Box_RecordsCount; //Only show this when in Data mode.
+  Gtk::Label m_Label_RecordsCount;
+  Gtk::Label m_Label_FoundCount;
+  Gtk::Button m_Button_FindAll;
 
   PlaceHolder* m_pBox_Mode; //Contains e.g. design mode notebook.
 
