@@ -25,7 +25,7 @@
 #include <libglom/connectionpool.h>
 #include <libglom/utils.h>
 
-#include <glibmm/convert.h>
+#include <glibmm/i18n.h>
 #include <sstream> //For stringstream
 
 #include <locale>     // for locale, time_put
@@ -33,38 +33,10 @@
 #include <iostream>   // for cout, endl
 #include <iomanip>
 #include <string.h> // for strlen, memset, strcmp
-#include <stdexcept>
-
-#include <glibmm/i18n.h>
-
-namespace
-{
-  char hextochar(guint8 hex)
-  {
-    if(hex < 10) return '0' + hex;
-    if(hex < 16) return 'a' - 10 + hex;
-    return '\0';
-  }
-
-  guint8 chartohex(char c)
-  {
-    if(c >= '0' && c <= '9') return c - '0';
-    if(c >= 'a' && c <= 'f') return c - 'a' + 10;
-    if(c >= 'A' && c <= 'F') return c - 'A' + 10;
-    return 0;
-  }
-}
 
 namespace Glom
 {
 
-
-unsigned int Conversions::get_stringstream_precision_default()
-{
-    static const unsigned int stringstream_precision_default = 15;
-    return stringstream_precision_default;
-}
-
 Glib::ustring Conversions::format_time(const tm& tm_data)
 {
   return format_time( tm_data, std::locale("") /* the user's current locale */ ); //Get the current locale.
@@ -217,22 +189,16 @@ Glib::ustring Conversions::format_tm(const tm& tm_data, const std::locale& local
   tp.put(the_stream /* iter to beginning of stream */, the_stream, ' ' /* fill */, &tm_data, format, format + strlen(format) /* 'E' */ /* use locale's alternative format */);
 
   Glib::ustring text = the_stream.str();
-  //std::cout << "DEBUG: format_tm(): result from tp.put: " << text << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": result from tp.put: " << text << std::endl;
 
   if(locale == std::locale("") /* The user's current locale */)
   {
     //Converts from the user's current locale to utf8. I would prefer a generic conversion from any locale,
     // but there is no such function, and it's hard to do because I don't know how to get the encoding name from the std::locale()
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     text = Glib::locale_to_utf8(text);
-#else
-    std::auto_ptr<Glib::Error> error;
-    text = Glib::locale_to_utf8(text, error);
-    // Ignore error for now
-#endif
   }
 
-  //std::cout << "DEBUG: format_tm(): returning: " << text << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": returning: " << text << std::endl;
   return text; //TODO: Use something like Glib::locale_to_utf8()?
 
   /*
@@ -265,9 +231,11 @@ Glib::ustring Conversions::format_tm(const tm& tm_data, const std::locale& local
   */
 }
 
+
 namespace //anonymous
 {
 
+/*
 class numpunct_thousands_separator: public std::numpunct<char>
 {
   //Override
@@ -276,6 +244,7 @@ class numpunct_thousands_separator: public std::numpunct<char>
     return "\3";
   };
 };
+*/
 
 class numpunct_no_thousands_separator: public std::numpunct<char>
 {
@@ -288,6 +257,7 @@ class numpunct_no_thousands_separator: public std::numpunct<char>
 
 } //anonymous namespace
 
+
 Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_type, const Gnome::Gda::Value& value, const NumericFormat& numeric_format)
 {
   return get_text_for_gda_value(glom_type, value, std::locale("") /* the user's current locale */, numeric_format); //Get the current locale.
@@ -318,7 +288,7 @@ double Conversions::get_double_for_gda_value_numeric(const Gnome::Gda::Value& va
       case G_TYPE_UINT64:
         return value.get_uint64();
       default:
-        std::cerr << "Conversions::get_double_for_gda_value_numeric(): expected NUMERIC but GdaValue type is: " << g_type_name(value.get_value_type()) << std::endl;
+        std::cerr << G_STRFUNC << ": expected NUMERIC but GdaValue type is: " << g_type_name(value.get_value_type()) << std::endl;
         return 0;
     }
   }
@@ -358,7 +328,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
       bool success;
       the_c_time = parse_date(value.get_string(), std::locale::classic(), success);
       if(!success)
-        std::cerr << "Conversions::get_text_for_gda_value(): Failed to convert string-represented date value" << std::endl;
+        std::cerr << G_STRFUNC << ": Failed to convert string-represented date value" << std::endl;
     }
     else if(value.get_value_type() == G_TYPE_DATE)
     {
@@ -373,7 +343,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
     }
     else
     {
-      std::cerr << "Conversions::get_text_for_gda_value(): glom field type is DATE but GdaValue type is: " << g_type_name(value.get_value_type()) << std::endl;
+      std::cerr << G_STRFUNC << ": glom field type is DATE but GdaValue type is: " << g_type_name(value.get_value_type()) << std::endl;
 
       // Default
       the_c_time.tm_mday = 1;
@@ -399,7 +369,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
       bool success;
       the_c_time = parse_time(value.get_string(), std::locale::classic(), success);
       if(!success)
-        std::cerr << "Conversions::get_text_for_gda_value(): Failed to convert string-represented time value" << std::endl;
+        std::cerr << G_STRFUNC << ": Failed to convert string-represented time value" << std::endl;
     }
     else if(value.get_value_type() == GDA_TYPE_TIME)
     {
@@ -413,7 +383,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
     }
     else
     {
-      std::cerr << "Conversions::get_text_for_gda_value(): glom field type is TIME but GdaValue type is: " << g_type_name(value.get_value_type()) << std::endl;
+      std::cerr << G_STRFUNC << ": glom field type is TIME but GdaValue type is: " << g_type_name(value.get_value_type()) << std::endl;
     }
 
     return format_time(the_c_time, locale, iso_format);
@@ -422,7 +392,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
   {
     if(value.get_value_type() != GDA_TYPE_NUMERIC && value.get_value_type() != G_TYPE_DOUBLE)
     {
-      std::cerr << "Conversions::get_text_for_gda_value(): glom field type is NUMERIC but GdaValue type is: " << g_type_name(value.get_value_type()) << std::endl;
+      std::cerr << G_STRFUNC << ": glom field type is NUMERIC but GdaValue type is: " << g_type_name(value.get_value_type()) << std::endl;
       return value.to_string();
     }
 
@@ -460,12 +430,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
       {
         std::string charset;
         Glib::get_charset(charset);
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
         Glib::ustring currency_symbol = Glib::convert_with_fallback(numeric_format.m_currency_symbol, charset, "UTF-8");
-#else
-        std::auto_ptr<Glib::Error> error;
-        Glib::ustring currency_symbol = Glib::convert_with_fallback(numeric_format.m_currency_symbol, charset, "UTF-8", error);
-#endif
         // Uses convert_with_fallback(.) for the curreny symbol to avoid an
         // exception where the operator<<'s automatic conversion fails.
         // Incompatible encodings are possible since the currency symbol itself
@@ -483,15 +448,10 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
     {
       // Converts from the user's current locale to utf8. I would prefer a generic conversion from any locale,
       // but there is no such function, and it's hard to do because I don't know how to get the encoding name from the std::locale()
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       text = Glib::locale_to_utf8(text);
-#else
-      std::auto_ptr<Glib::Error> error;
-      text = Glib::locale_to_utf8(text, error);
-#endif
     }
 
-    //std::cout << "DEBUG: Conversions::get_text_for_gda_value(): number=" << number << ", text=" << text << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": number=" << number << ", text=" << text << std::endl;
     return text; //Do something like Glib::locale_to_utf(), but with the specified locale instead of the current locale.
   }
   else if(glom_type == Field::TYPE_TEXT)
@@ -513,12 +473,12 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
     //- UI-visible strings, but images should never be shown as text in the UI. 
     //- Values in SQL queries, but we only do that for clauses (where/sort/order) 
     //  which should never use image values.
-    std::cerr << "Conversions::get_text_for_gda_value(): Unexpected TYPE_IMAGE field type: " << glom_type << std::endl;
+    std::cerr << G_STRFUNC << ": Unexpected TYPE_IMAGE field type: " << glom_type << std::endl;
     return Glib::ustring();
   }
   else
   {
-    std::cerr << "Conversions::get_text_for_gda_value(): Unexpected glom field type: " << glom_type << std::endl;
+    std::cerr << G_STRFUNC << ": Unexpected glom field type: " << glom_type << std::endl;
     return value.to_string();
   }
 }
@@ -620,7 +580,7 @@ Gnome::Gda::Value Conversions::parse_value(Field::glom_field_type glom_type, con
     double the_number = 0;
     the_stream >> the_number;  //TODO: Does this throw any exception if the text is an invalid number?
 
-    //std::cout << "DEBUG: Conversions::parse_value(): text=" << text_to_parse << ", number=" << the_number << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": text=" << text_to_parse << ", number=" << the_number << std::endl;
     
 
     GdaNumeric gda_numeric = {0, 0, 0, 0};
@@ -656,7 +616,7 @@ Gnome::Gda::Value Conversions::parse_value(Field::glom_field_type glom_type, con
   {
     //This function is only used for :
     //- UI-visible strings, but images should never be entered as text in the UI. 
-    std::cerr << "Conversions::parse_value(): Unexpected TYPE_IMAGE field type: " << glom_type << std::endl;
+    std::cerr << G_STRFUNC << ": Unexpected TYPE_IMAGE field type: " << glom_type << std::endl;
     return Gnome::Gda::Value();
   }
 
@@ -802,7 +762,7 @@ tm Conversions::parse_time(const Glib::ustring& text, bool& success)
 
 tm Conversions::parse_time(const Glib::ustring& text, const std::locale& locale, bool& success)
 {
-  //std::cout << "parse_time(): text=" << text << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": text=" << text << std::endl;
   //The sequence of statements here seems to be very fragile. If you move things then it stops working.
 
   //return parse_tm(text, locale, 'X' /* time */);
@@ -865,7 +825,7 @@ tm Conversions::parse_time(const Glib::ustring& text, const std::locale& locale,
   lastchar = strptime(text.c_str(), "%X" /* The time, using the locale's time format. */, &the_c_time);
   if(lastchar)
   {
-    //std::cout << "DEBUG: parse_time(): %X: text=" << text << " was parsed as: hour=" << the_c_time.tm_hour << ", min=" << the_c_time.tm_min  << ", sec=" << the_c_time.tm_sec << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": %X: text=" << text << " was parsed as: hour=" << the_c_time.tm_hour << ", min=" << the_c_time.tm_min  << ", sec=" << the_c_time.tm_sec << std::endl;
     success = true;
     return the_c_time;
   }
@@ -876,7 +836,7 @@ tm Conversions::parse_time(const Glib::ustring& text, const std::locale& locale,
   lastchar = strptime(text.c_str(), "%c" /* alternative 12-hour clock */, &the_c_time);
   if(lastchar)
   {
-    //std::cout << "DEBUG: parse_time(): %c: text=" << text << " was parsed as: hour=" << the_c_time.tm_hour << ", min=" << the_c_time.tm_min  << ", sec=" << the_c_time.tm_sec << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": %c: text=" << text << " was parsed as: hour=" << the_c_time.tm_hour << ", min=" << the_c_time.tm_min  << ", sec=" << the_c_time.tm_sec << std::endl;
     success = true;
     return the_c_time;
   }
@@ -886,7 +846,7 @@ tm Conversions::parse_time(const Glib::ustring& text, const std::locale& locale,
   lastchar = strptime(text.c_str(), "%I : %M %p" /* 12 hours clock with AM/PM, without seconds. */, &the_c_time);
   if(lastchar)
   {
-    //std::cout << "DEBUG: parse_time(): %I : %M %p: text=" << text << " was parsed as: hour=" << the_c_time.tm_hour << ", min=" << the_c_time.tm_min  << ", sec=" << the_c_time.tm_sec << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": %I : %M %p: text=" << text << " was parsed as: hour=" << the_c_time.tm_hour << ", min=" << the_c_time.tm_min  << ", sec=" << the_c_time.tm_sec << std::endl;
     success = true;
     return the_c_time;
   }
