@@ -60,7 +60,6 @@ public:
   /** Update a portal if a relevant value in its parent table has changed.
    *
    * @param foreign_key_value: The value that should be found in this table.
-   * @param from_table_primary_key_value The primary key of the parent record's table, used to associate new related records.
    */
   bool refresh_data_from_database_with_foreign_key(const Gnome::Gda::Value& foreign_key_value);
 
@@ -82,7 +81,7 @@ public:
   void get_suitable_record_to_view_details(const Gnome::Gda::Value& primary_key_value, Glib::ustring& table_name, Gnome::Gda::Value& table_primary_key_value) const;
 
 protected:
-  virtual type_vecLayoutFields get_fields_to_show() const; //override
+  virtual type_vecConstLayoutFields get_fields_to_show() const; //override
     
   //Implementations of pure virtual methods from Base_DB_Table_Data:
   virtual sharedptr<Field> get_field_primary_key() const;
