@@ -131,6 +131,12 @@ public:
   virtual void set_value_selected(const sharedptr<const LayoutItem_Field>& layout_item, const Gnome::Gda::Value& value);
 
   bool get_is_first_row(const Gtk::TreeModel::iterator& iter) const;
+
+  /** Check whether the row is the last (non-placeholder) row.
+   * This will also return true if @a iter is the placeholder row,
+   * but this should be used to identify the last real row.
+   * @see get_is_placeholder_row()
+   */
   bool get_is_last_row(const Gtk::TreeModel::iterator& iter) const;
 
   /** @result Whether this is a blank row where date for a new row should be entered
@@ -236,17 +242,27 @@ public:
   typedef sigc::signal<void> type_signal_sort_clause_changed;
   type_signal_sort_clause_changed signal_sort_clause_changed();
 
+  /** Get the last row.
+   * This will never return the placeholder row. 
+   */
+  Gtk::TreeModel::iterator get_last_row();
+  
+  /** Get the last row.
+   * This will never return the placeholder row. 
+   */
+  Gtk::TreeModel::iterator get_last_row() const;
 
-  virtual Gtk::TreeModel::iterator get_last_row();
-  virtual Gtk::TreeModel::iterator get_last_row() const;
-
-  virtual void set_open_button_title(const Glib::ustring& title);
+  void set_open_button_title(const Glib::ustring& title);
 
 
   /** Add a new row to the list, for the user to enter record details,
    * adding the generated primary key if necessary.
    */
   bool start_new_record();
+  
+  /** Request a height for this widget, based on the number of rows to show.
+   */
+  void set_height_rows(guint rows);
 
 private:
 
@@ -282,16 +298,16 @@ private:
   type_list_indexes get_data_model_column_index(const sharedptr<const LayoutItem_Field>& layout_item_field, bool including_specified_field_layout = true) const;
 
 protected:
-  virtual void setup_menu();
+  void setup_menu();
 
   /// A common handler for the edit button, the context menu, etc.
   void do_user_requested_edit();
 
 private:
-  virtual Gnome::Gda::Value treeview_get_key(const Gtk::TreeModel::iterator& row) const;
+  Gnome::Gda::Value treeview_get_key(const Gtk::TreeModel::iterator& row) const;
 
   ///Add a blank row, or return the existing blank row if there already is one.
-  //virtual Gtk::TreeModel::iterator get_next_available_row_with_add_if_necessary();
+  //Gtk::TreeModel::iterator get_next_available_row_with_add_if_necessary();
 
   //Signal handlers:
   #ifdef GLOM_ENABLE_MAEMO
@@ -305,15 +321,15 @@ private:
 
   //TODO: Remove virtuals after checking that there are no method overrides:
   #ifndef GLOM_ENABLE_MAEMO
-  virtual void on_treeview_cell_edited(const Glib::ustring& path_string, const Glib::ustring& new_text, int model_column_index, int data_model_column_index);
-  virtual void on_treeview_cell_edited_bool(const Glib::ustring& path_string, int model_column_index, int data_model_column_index);
+  void on_treeview_cell_edited(const Glib::ustring& path_string, const Glib::ustring& new_text, int model_column_index, int data_model_column_index);
+  void on_treeview_cell_edited_bool(const Glib::ustring& path_string, int model_column_index, int data_model_column_index);
   void on_idle_treeview_cell_edited_revert(const Gtk::TreeModel::Row& row, guint model_column_index);
 
   bool on_treeview_column_drop(Gtk::TreeView* treeview, Gtk::TreeViewColumn* column, Gtk::TreeViewColumn* prev_column, Gtk::TreeViewColumn* next_column);
   void on_treeview_columns_changed();
 
-  virtual bool on_button_press_event_Popup(GdkEventButton* event);
-  virtual void on_treeview_button_press_event(GdkEventButton* event);
+  bool on_button_press_event_Popup(GdkEventButton* event);
+  void on_treeview_button_press_event(GdkEventButton* event);
 
 protected:
   void on_MenuPopup_activate_Edit();
@@ -328,8 +344,8 @@ private:
 #endif
 
   #ifndef GLOM_ENABLE_MAEMO
-  virtual bool on_treeview_columnheader_button_press_event(GdkEventButton* event);
-  virtual void on_treeview_column_clicked(int model_column_index);
+  bool on_treeview_columnheader_button_press_event(GdkEventButton* event);
+  void on_treeview_column_clicked(int model_column_index);
   void on_treeview_column_resized(int model_column_index, DbTreeViewColumnGlom* view_column);
   void on_idle_row_edit();
   void on_cell_button_clicked(const Gtk::TreeModel::Path& path);
@@ -372,7 +388,7 @@ private:
    */
   void show_hint_model();
 
-  int get_fixed_cell_height();
+  guint get_fixed_cell_height();
 
   //TODO: Remove this and use AppGlom::get_application() instead?
   Application* get_application();
@@ -492,7 +508,7 @@ private:
   ModelColumnsEmptyHint m_columns_hint;
   Glib::RefPtr<Gtk::ListStore> m_model_hint;
 
-  int m_fixed_cell_height;
+  guint m_fixed_cell_height;
 
 private:
 
