@@ -18,10 +18,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_MODE_DATA_DIALOG_FORMATTING_H
-#define GLOM_MODE_DATA_DIALOG_FORMATTING_H
+#ifndef GLOM_MODE_DESIGN_DIALOG_FORMATTING_H
+#define GLOM_MODE_DESIGN_DIALOG_FORMATTING_H
 
-#include <gtkmm/dialog.h>
+#include <gtkmm.h>
 #include <glom/utility_widgets/dialog_properties.h>
 #include <libglom/document/view.h>
 #include <glom/box_withbuttons.h>
@@ -32,6 +32,9 @@
 namespace Glom
 {
 
+/** This dialog lets the user choose the formatting for non-field items.
+ * Field items should use Dialog_FieldLayout instead.
+ */
 class Dialog_Formatting
  : public Gtk::Dialog,
    public View_Composite_Glom //Give it access to the document.
@@ -44,9 +47,9 @@ public:
    * @param document The document, so that the dialog can load the previous layout, and save changes.
    * @param field The starting item information.
    */
-  void set_item(const sharedptr<const LayoutItem_WithFormatting>& field);
+  void set_item(const sharedptr<const LayoutItem_WithFormatting>& field, bool show_numeric);
 
-  /** Set the @a layout_item's formatting to the formatting specified in the 
+  /** Set the @a layout_item's formatting to the formatting specified in the
    * dialog by the user.
    */
   void use_item_chosen(const sharedptr<LayoutItem_WithFormatting>& layout_item);
@@ -59,4 +62,4 @@ private:
 
 } //namespace Glom
 
-#endif //GLOM_MODE_DATA_DIALOG_FORMATTING_H
+#endif // GLOM_MODE_DESIGN_DIALOG_FORMATTING_H
