@@ -18,8 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_CANVAS_PRINT_LAYOUT_EDIT_H
-#define GLOM_CANVAS_PRINT_LAYOUT_EDIT_H
+#ifndef GLOM_PRINT_LAYOUT_CANVAS_PRINT_LAYOUT_H
+#define GLOM_PRINT_LAYOUT_CANVAS_PRINT_LAYOUT_H
 
 #include <glom/base_db.h>
 #include <glom/utility_widgets/canvas/canvas_editable.h>
@@ -28,7 +28,6 @@
 #include <gtkmm/uimanager.h>
 #include <gtkmm/toggleaction.h>
 #include <gtkmm/pagesetup.h>
-#include <goocanvasmm/table.h>
 
 namespace Glom
 {
@@ -52,7 +51,6 @@ public:
   Glib::RefPtr<Gtk::PageSetup> get_page_setup();
 
   void set_zoom_percent(guint percent);
-  guint get_zoom_percent() const;
  
   /** Hide the bounds rectangle and the margin lines:
    */
@@ -80,9 +78,9 @@ private:
   void fill_with_data_portal(const Glib::RefPtr<CanvasLayoutItem>& canvas_item, const Gnome::Gda::Value& foreign_key_value);
   static void set_canvas_item_field_value(const Glib::RefPtr<Goocanvas::Item> canvas_item, const sharedptr<LayoutItem_Field> field, const Gnome::Gda::Value& value);
 
-  static Glib::RefPtr<Goocanvas::Item> get_canvas_table_cell_child(const Glib::RefPtr<Goocanvas::Table>& table, int row, int col); //TODO: Add this to GooCanvas::Table.
+  static Glib::RefPtr<Goocanvas::Item> get_canvas_table_cell_child(const Glib::RefPtr<Goocanvas::Table>& table, int row, int col); //TODO: Add this to Goocanvas::Table.
   
-  type_vecLayoutFields get_portal_fields_to_show(const sharedptr<LayoutItem_Portal>& portal);
+  type_vecConstLayoutFields get_portal_fields_to_show(const sharedptr<LayoutItem_Portal>& portal);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   sharedptr<LayoutItem_Portal> offer_related_records(const sharedptr<LayoutItem_Portal>& portal, Gtk::Window* parent);
@@ -124,5 +122,4 @@ private:
 
 } //namespace Glom
 
-#endif //GLOM_CANVAS_PRINT_LAYOUT_EDIT_H
-
+#endif // GLOM_PRINT_LAYOUT_CANVAS_PRINT_LAYOUT_H
