@@ -175,7 +175,6 @@ Glib::RefPtr<Goocanvas::Polyline> CanvasGroupGrid::create_grid_or_rule_line(doub
     line->property_stroke_color() = "green";
   else
     line->property_stroke_color() = "gray";
-
   return line;
 }
 
@@ -216,7 +215,10 @@ void CanvasGroupGrid::create_lines()
     m_grid_rules_group->remove_child(0);
 
   //Fill the parent canvas with lines:
-  double left, top, right, bottom = 0.0;
+  double left = 0.0;
+  double top = 0.0;
+  double right = 0.0;
+  double bottom = 0.0;
   Goocanvas::Canvas* canvas = get_canvas();
   if(canvas)
     canvas->get_bounds(left, top, right, bottom);
