@@ -24,7 +24,8 @@
 #include <glom/utils_ui.h>
 #include <glom/glade_utils.h>
 #include <libglom/data_structure/glomconversions.h>
-//#include <sstream> //For stringstream
+#include <glom/utility_widgets/dialog_image_load_progress.h>
+#include <glom/utility_widgets/dialog_image_save_progress.h>
 
 #include <iostream>   // for cout, endl
 
@@ -56,7 +57,7 @@ void ImageGlom::init()
 
   setup_menu_usermode();
 
-  m_image.set_size_request(150, 150);
+  //m_image.set_size_request(150, 150);
   m_image.show();
 
   m_frame.set_shadow_type(Gtk::SHADOW_ETCHED_IN); //Without this, the image widget has no borders and is completely invisible when empty.
@@ -151,8 +152,6 @@ bool ImageGlom::get_has_original_data() const
 void ImageGlom::set_pixbuf(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf)
 {
   m_pixbuf_original = pixbuf;
-  m_image.set(m_pixbuf_original);
-
   scale();
 }
 
@@ -165,8 +164,8 @@ void ImageGlom::set_value(const Gnome::Gda::Value& value)
 
   if(pixbuf)
   {
-    set_pixbuf(pixbuf);
     scale();
+    set_pixbuf(pixbuf);
   }
   else
   {
@@ -233,8 +232,8 @@ Gnome::Gda::Value ImageGlom::get_value() const
     {
       gchar* buffer = 0;
       gsize buffer_size = 0;
-      std::list<Glib::ustring> list_keys;
-      std::list<Glib::ustring> list_values;
+      std::vector<Glib::ustring> list_keys;
+      std::vector<Glib::ustring> list_values;
       //list_keys.push_back("quality"); //For jpeg only.
       //list_values.push_back("95");
 
@@ -281,11 +280,26 @@ void ImageGlom::scale()
     const Gtk::Allocation allocation = m_image.get_allocation();
     const int pixbuf_height = pixbuf->get_height();
     const int pixbuf_width = pixbuf->get_width();
+    
+    int allocation_height = allocation.get_height();
+    int allocation_width = allocation.get_width();
+    
+    //If the Image widget has expanded to be big enough for the original image,
+    //it might be huge. We don't want that.
+    //Scaling it down will reduce how much it requests.
+    if(allocation_width >= 400)
+      allocation_width = 400;
+      
+    if(allocation_height >= 400)
+      allocation_height = 400;
+      
+    //std::cout << "pixbuf_height=" << pixbuf_height << ", pixbuf_width=" << pixbuf_width << std::endl;
+    //std::cout << "allocation_height=" << allocation.get_height() << ", allocation_width=" << allocation.get_width() << std::endl;
 
-    if( (pixbuf_height > allocation.get_height()) ||
-        (pixbuf_width > allocation.get_width()) )
+    if( (pixbuf_height >allocation_height ) ||
+        (pixbuf_width > allocation_width) )
     {
-      if(allocation.get_height() > 10 || allocation.get_width() > 10)
+      if(allocation_height > 10 || allocation_width > 10)
       {
         Glib::RefPtr<Gdk::Pixbuf> pixbuf_scaled = Utils::image_scale_keeping_ratio(pixbuf, allocation.get_height(), allocation.get_width());
         if(!pixbuf_scaled)
@@ -294,7 +308,7 @@ void ImageGlom::scale()
         }
         else 
         {
-          //Don't set a new pixbuf if the dimenstions have not changed:
+          //Don't set a new pixbuf if the dimensions have not changed:
           Glib::RefPtr<const Gdk::Pixbuf> pixbuf_in_image;
 
           if(m_image.get_storage_type() == Gtk::IMAGE_PIXBUF) //Prevent warning.
@@ -310,19 +324,152 @@ void ImageGlom::scale()
   //  g_warning("ImageGlom::scale(): attempt to scale a null pixbuf.");
 }
 
-void ImageGlom::on_menupopup_activate_select_file()
+void ImageGlom::on_menupopup_activate_open_file()
 {
-  if(m_read_only)
+  open_with();
+}
+
+void ImageGlom::on_menupopup_activate_open_file_with()
+{
+  Application* pApp = get_application();
+
+  //Offer the user a choice of suitable applications:
+  Gtk::AppChooserDialog dialog(GLOM_IMAGE_FORMAT_MIME_TYPE);
+  if(pApp)
+    dialog.set_transient_for(*pApp);
+
+  if(dialog.run() != Gtk::RESPONSE_OK)
+    return;
+  
+  Glib::RefPtr<Gio::AppInfo> app_info = dialog.get_app_info();
+  if(!app_info)
+  {
+    std::cerr << G_STRFUNC << ": app_info was null." << std::endl;
+  }
+  
+  open_with(app_info);
+}
+
+void ImageGlom::open_with(const Glib::RefPtr<Gio::AppInfo>& app_info)
+{
+  //Get a temporary file path:
+  std::string filepath;
+  const int filehandle = Glib::file_open_tmp(filepath);
+  ::close(filehandle);
+  
+  if(filepath.empty())
+  {
+    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() returned an empty filepath" << std::endl;
+    return;
+  }
+  
+  const Glib::ustring uri = Glib::filename_to_uri(filepath);
+  
+  if(!save_file(uri))
     return;
 
-  //TODO: Use Hildon::FileChooser for Maemo.
-  Gtk::FileChooserDialog dialog(_("Choose Image"), Gtk::FILE_CHOOSER_ACTION_OPEN);
+  if(app_info)
+  {
+    std::vector<std::string> vec_uris;
+    vec_uris.push_back(uri);
+    app_info->launch_uris(vec_uris, 0); //TODO: Get a GdkAppLaunchContext?
+    
+    //TODO Use this instead when we can use glibmm 3.2:
+    //app_info->launch_uri(uri);
+  }
+  else
+  {
+    //TODO: Avoid duplication in xsl_utils.cc, by moving this into a utility function:  
+#ifdef G_OS_WIN32
+    // gtk_show_uri doesn't seem to work on Win32, at least not for local files
+    // We use Windows API instead.
+    // TODO: Check it again and file a bug if necessary.
+    // TODO: and this might not be necessary with Gio::AppInfo::launch_default_for_uri().
+    //   Previously we used gtk_show_uri().
+    ShellExecute(0, "open", uri.c_str(), 0, 0, SW_SHOW);
+#else
+    Gio::AppInfo::launch_default_for_uri(uri);
+#endif //G_OS_WIN32
+  }
+}
 
+
+static void set_file_filter_images(Gtk::FileChooser& file_chooser)
+{
   //Get image formats only:
   Glib::RefPtr<Gtk::FileFilter> filter = Gtk::FileFilter::create();
   filter->set_name(_("Images"));
   filter->add_pixbuf_formats();
-  dialog.add_filter(filter);
+  file_chooser.add_filter(filter);
+  
+  filter = Gtk::FileFilter::create();
+  filter->set_name(_("All Files"));
+  filter->add_pattern("*");
+  file_chooser.add_filter(filter);
+}
+
+void ImageGlom::on_menupopup_activate_save_file()
+{
+  Application* pApp = get_application();
+
+  Gtk::FileChooserDialog dialog(_("Save Image"), Gtk::FILE_CHOOSER_ACTION_SAVE);
+  if(pApp)
+    dialog.set_transient_for(*pApp);
+          
+  set_file_filter_images(dialog);
+
+  dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+  dialog.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_OK);
+  const int response = dialog.run();
+  dialog.hide();
+  if(response != Gtk::RESPONSE_OK)
+    return;
+    
+  const Glib::ustring uri = dialog.get_uri();
+  if(uri.empty())
+    return;
+    
+  save_file(uri);
+}
+
+bool ImageGlom::save_file(const Glib::ustring& uri)
+{
+  DialogImageSaveProgress* dialog_save = 0;
+  Utils::get_glade_widget_derived_with_warning(dialog_save);
+  if(!dialog_save)
+    return false;
+    
+  // Automatically delete the dialog when we no longer need it:
+  std::auto_ptr<Gtk::Dialog> dialog_keeper(dialog_save);
+
+  Application* pApp = get_application();
+  if(pApp)
+    dialog_save->set_transient_for(*pApp);
+
+  const GdaBinary* gda_binary = gda_value_get_binary(m_original_data.gobj());
+  if(!gda_binary)
+    return false;
+
+  dialog_save->set_image_data(*gda_binary);
+  dialog_save->save(uri);
+
+  dialog_save->run();
+  return true;
+}
+
+void ImageGlom::on_menupopup_activate_select_file()
+{
+  if(m_read_only)
+    return;
+    
+  Application* pApp = get_application();
+
+  //TODO: Use Hildon::FileChooser for Maemo.
+  Gtk::FileChooserDialog dialog(_("Choose Image"), Gtk::FILE_CHOOSER_ACTION_OPEN);
+  if(pApp)
+    dialog.set_transient_for(*pApp);
+          
+  set_file_filter_images(dialog);
 
   dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   dialog.add_button(_("Select"), Gtk::RESPONSE_OK);
@@ -334,14 +481,13 @@ void ImageGlom::on_menupopup_activate_select_file()
     const Glib::ustring uri = dialog.get_uri();
     if(!uri.empty())
     {
-      Dialog_Image_Progress* dialog;
+      DialogImageLoadProgress* dialog;
       Utils::get_glade_widget_derived_with_warning(dialog);
       if(dialog)
       {
         // Automatically delete the dialog when we no longer need it:
         std::auto_ptr<Gtk::Dialog> dialog_keeper(dialog);
 
-        Application* pApp = get_application();
         if(pApp)
           dialog->set_transient_for(*pApp);
 
@@ -359,7 +505,6 @@ void ImageGlom::on_menupopup_activate_select_file()
           gda_value_take_binary(m_original_data.gobj(), bin);
 
           m_pixbuf_original = dialog->get_pixbuf();
-          m_image.set(m_pixbuf_original); //Load the image.
           scale();
           signal_edited().emit();
         }
@@ -407,8 +552,7 @@ void ImageGlom::on_menupopup_activate_copy()
   Glib::RefPtr<Gtk::Clipboard> refClipboard = Gtk::Clipboard::get();
 
   //Targets:
-  std::list<Gtk::TargetEntry> listTargets;
-
+  std::vector<Gtk::TargetEntry> listTargets;
   listTargets.push_back( Gtk::TargetEntry(GLOM_IMAGE_FORMAT_MIME_TYPE) );
 
   refClipboard->set( listTargets, sigc::mem_fun(*this, &ImageGlom::on_clipboard_get), sigc::mem_fun(*this, &ImageGlom::on_clipboard_clear) );
@@ -425,9 +569,8 @@ void ImageGlom::on_clipboard_received_image(const Glib::RefPtr<Gdk::Pixbuf>& pix
     m_original_data = Gnome::Gda::Value();
 
     m_pixbuf_original = pixbuf;
-
-    m_image.set(m_pixbuf_original); //Load the image.
     scale();
+
     signal_edited().emit();
   }
 }
@@ -460,11 +603,24 @@ void ImageGlom::setup_menu_usermode()
   m_refActionGroup_UserModePopup = Gtk::ActionGroup::create();
 
   m_refActionGroup_UserModePopup->add(Gtk::Action::create("ContextMenu_UserMode", "Context Menu") );
+  
+  m_refActionOpenFile =  Gtk::Action::create("ContextOpenFile", Gtk::Stock::OPEN);
+  m_refActionOpenFileWith =  Gtk::Action::create("ContextOpenFileWith", Gtk::Stock::OPEN, _("Open With"));
+  m_refActionSaveFile =  Gtk::Action::create("ContextSaveFile", Gtk::Stock::SAVE);
   m_refActionSelectFile =  Gtk::Action::create("ContextSelectFile", Gtk::Stock::EDIT, _("Choose File"));
   m_refActionCopy = Gtk::Action::create("ContextCopy", Gtk::Stock::COPY);
   m_refActionPaste = Gtk::Action::create("ContextPaste", Gtk::Stock::PASTE);
   m_refActionClear = Gtk::Action::create("ContextClear", Gtk::Stock::CLEAR);
 
+  m_refActionGroup_UserModePopup->add(m_refActionOpenFile,
+    sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_open_file) );
+
+  m_refActionGroup_UserModePopup->add(m_refActionOpenFileWith,
+    sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_open_file_with) );
+    
+  m_refActionGroup_UserModePopup->add(m_refActionSaveFile,
+    sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_save_file) );
+    
   m_refActionGroup_UserModePopup->add(m_refActionSelectFile,
     sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_select_file) );
 
@@ -488,6 +644,9 @@ void ImageGlom::setup_menu_usermode()
     Glib::ustring ui_info = 
         "<ui>"
         "  <popup name='ContextMenu_UserMode'>"
+        "    <menuitem action='ContextOpenFile'/>"
+        "    <menuitem action='ContextOpenFileWith'/>"
+        "    <menuitem action='ContextSaveFile'/>"
         "    <menuitem action='ContextSelectFile'/>"
         "    <menuitem action='ContextCopy'/>"
         "    <menuitem action='ContextPaste'/>"
